@@ -98,9 +98,10 @@ class Camera(BaseCamera):
         if "gain" in capa:
             gain = cc.get_gain()
             gaindef = cc.getdef_gain()
-        gamma = cc.get_gamma()
-        gammadef = cc.getdef_gamma()
-        print(f"i... EXPOAUTO == {expo_auto} vs def={expo_autodef};  gamma={gamma}")
+        if "gamma" in capa:
+            gamma = cc.get_gamma()
+            gammadef = cc.getdef_gamma()
+        print(f"i... EXPOAUTO == {expo_auto} vs def={expo_autodef}; ")
 
 
         nfrm = 0
