@@ -186,6 +186,12 @@ class V4L2_CTL():
     def _list_controls(self):
         controls = []
         #print("Executing: " + ' '.join(['v4l2-ctl', '-d', self.device, '-l']))
+        CMD = ['which','v4l2-ctl']
+        child = sp.Popen( CMD, stdout = sp.PIPE )
+        if child.returncode != 0:
+            print("X... install v4l2-ctl:  apt install v4l-utils")
+            sys.exit(1)
+
         CMDL = ['v4l2-ctl', '-d', self.device, '-l']
         #print("i... ", CMDL )
         output = sp.check_output( CMDL ).decode(
