@@ -67,7 +67,15 @@ if  not("debug" in config.CONFIG):
 cross_dx, cross_dy = 0,0
 cross_on = False
 
+save_bg = False
+frame_bg = None
+frame_bg2 = None
+frame_mask = None
+frame_mask_inv = None
+sub_bg = False
 
+# background path
+BGFILE = os.path.expanduser('~/.config/flashcam/background.jpg')
 
 
 
@@ -138,8 +146,15 @@ setInterval(doDate, 200);
   <div class="btn-group" style="width:100%">
       <button style="width:20%" name="down2" value="DOWN2">down2</button>
   </div>
+<hr>
+  <div class="btn-group" style="width:100%">
+      <button style="width:8%" name="savebg" value="SAVEBG">SAVEBG</button>
+      <button style="width:8%" name="subbg" value="SUBBG">SUBBG</button>
+  </div>
 </form>
+ <img src="{{url_bg}}" alt="Smiley face"  height="120" width="160" />
 
+operate real from web
   </body>
 </html>
 
@@ -168,7 +183,7 @@ def crossonw( img,  dix, diy):
 @auth.verify_password
 @app.route("/cross", methods=['GET', 'POST'])
 def cross():
-    global cross_dx, cross_dy, cross_on
+    global cross_dx, cross_dy, cross_on, save_bg, sub_bg
 
     # i will read it from file
     crocfg = os.path.expanduser("~/.config/flashcam/cross.txt")
@@ -178,6 +193,12 @@ def cross():
 
     print(request.method)
     if request.method == 'POST':
+        if request.form.get('savebg') == 'SAVEBG':
+            print("i... saving BG" )
+            save_bg = True
+        if request.form.get('subbg') == 'SUBBG':
+            print("i... substracting  BG" )
+            sub_bg = not( sub_bg)
         if cross_on:
             if request.form.get('left2') == 'LEFT2':
                 print("left2")
@@ -222,7 +243,8 @@ def cross():
     logthis( " / remote      = "+request.remote_addr )
     logthis( " / remote xreal= "+remote_ip )
     url = url_for('video')
-    return render_template_string(index_page, url=url)
+    url_bg = url_for('background')
+    return render_template_string(index_page, url=url, url_bg  = url_bg)
 
 
 
@@ -268,7 +290,8 @@ def index():
     logthis( " / remote xreal= "+remote_ip )
     url = url_for('video')
     print(url)
-    return render_template_string(index_page, url=url)
+    url_bg = url_for('background')
+    return render_template_string(index_page, url=url, url_bg  = url_bg)
 
 @app.route('/refresh30')
 @auth.login_required
@@ -280,11 +303,55 @@ def index30():
     logthis( " / remote xreal= "+remote_ip )
     url = url_for('video')
     print(url)
-    return render_template_string(index_page_refresh30, url=url)
+    url_bg = url_for('background')
+    return render_template_string(index_page_refresh30, url=url, url_bg  = url_bg)
 
 
 #('index.html')
 
+
+@app.route('/background')
+@auth.login_required
+def background():
+    global  save_bg, frame_bg, frame_bg2, frame_mask, frame_mask_inv, BGFILE
+    if not(frame_bg is None):
+        # print(frame_bg, "BGFRAME")
+        # # frame = cv2.imdecode(frame_bg, cv2.IMREAD_COLOR)
+        r, jpg = cv2.imencode('.jpg', frame_bg)
+        print("RESPONSE BACKGROUND",r)
+    else:
+        if os.path.exists( BGFILE):
+            blank = cv2.imread( BGFILE )
+            # print( blank )
+            # # frame_bg = cv2.imdecode(blank, cv2.IMREAD_COLOR)
+            frame_bg = blank.copy() # propagate to the system
+            r, jpg = cv2.imencode('.jpg', blank)
+            print("OLD BACKGROUND IMAGE FOUND",r, frame_bg.shape)
+        else:
+            blank = np.zeros((480,640,3), np.uint8)
+            frame_bg = blank.copy() # propagate to the system
+            #frame = cv2.imdecode(blank, cv2.IMREAD_COLOR)
+            r, jpg = cv2.imencode('.jpg', blank)
+            print("NO BACKGROUND - black image",r)
+
+    # create mask----------------- appears not usefull-----
+    # frame_mask = np.random.randint(2,
+    #                                size = (frame_bg.shape[0],frame_bg.shape[1] ),
+    #                                dtype=np.uint8) #
+    # frame_mask = 255 *np.ones( (frame_bg.shape[0],frame_bg.shape[1] ),
+    #                                dtype=np.uint8) #
+    # frame_mask[:230,:] = 0
+    # frame_mask[-20:-1,:] = 0
+    # frame_mask_inv = 255 - frame_mask
+    # r, jpg = cv2.imencode('.jpg', frame_mask)
+
+    # send direct JPG
+    return Response( jpg.tobytes() , direct_passthrough= True)
+    # rather than <img />
+    return Response(b'--frame\r\n' b'Content-Type: image/jpeg\r\n\r\n' + jpg.tobytes() + b'\r\n\r\n', mimetype='multipart/x-mixed-replace; boundary=frame')
+
+
+
 @app.route('/video')
 @auth.login_required
 def video():
@@ -310,11 +377,14 @@ def gen(camera, remote_ip, blend=False, bigtext=True):
     MAY do modifications per USER ! BUT any fraME MOD => IS SENT TO ALL!
     can send only some frames
     """
+    global save_bg, frame_bg, frame_bg2, frame_mask, frame_mask_inv
     print("D... entered gen, camera = ", camera)
     framecnt = 0
     framecnttrue = 0
     ss_time = 0
 
+
+
     while True:
         time.sleep(0.1)
         framecnt+=1
@@ -329,30 +399,34 @@ def gen(camera, remote_ip, blend=False, bigtext=True):
 
         if cross_on:
             frame = crossonw( frame, cross_dx, cross_dy )
-        # if bigtext:
-        #     frame = cv2.putText(
-        #         img = frame,
-        #         text = dt.datetime.now().strftime("%H:%M:%S"),
-        #         org = (10, 100),
-        #         fontFace = cv2.FONT_HERSHEY_DUPLEX,
-        #         fontScale = 2.0,
-        #         color = (125, 246, 55),
-        #         thickness = 3
-        #     )
-        #     frame = cv2.putText(
-        #         img = frame,
-        #         text = f"{framecnt:6d} {ss_time:.3f}",
-        #         org = (10, 50),
-        #         fontFace = cv2.FONT_HERSHEY_DUPLEX,
-        #         fontScale = 1.0,
-        #         color = (125, 246, 55),
-        #         thickness = 1
-        #     )
-        #----- i dont send None now, but this helped to avoid crash
+
+        if save_bg:# before .tobytes()
+            cv2.imwrite( BGFILE , frame )
+            frame_bg = frame.copy()
+            frame_bg2 = cv2.imencode('.jpg', frame_bg)[1].tobytes()
+            save_bg = False
+
+        if sub_bg and  not(frame_bg is None):
+            # print( frame_mask.shape )
+            # print( frame_bg.shape )
+            # print( frame.shape )
+            frame1 = cv2.subtract(frame , frame_bg ) #, mask = frame_mask
+            # frame = cv2.subtract( frame_bg, frame) # inverse...
+            # frame = cv2.absdiff(frame , frame_bg) # returns abs value...
+            # frame = cv2.absdiff(frame_bg, frame) # returns abs value...
+
+            # frame 1 is difference...
+            frame1[:22,:] = frame [:22,:]
+            frame1[-22:,:] = frame [-22:,:]
+            frame = frame1
+            #frame = cv2.add( frame, frame1, mask = frame_mask_inv )
+
         if not(frame is None):
             frame=cv2.imencode('.jpg', frame)[1].tobytes()
         else:
             continue
+
+
         stop = dt.datetime.now()
         ss_time = (stop-start).total_seconds()
 
